@@ -24,15 +24,16 @@
 # The main control interface between control_head and remote_radio is via a TCP port;
 # this uses very low bandwidth.  All functional control, including CW keying, is done via this port.
 #
-# There are 3 additional ports, all UDP, using low to moderate bandwidth:
-# -- Receive graph/waterfall data from the remote_radio Quisk
-# -- Receive radio sound from the remote_radio Quisk
-# -- Send mic sound to the remote_radio Quisk
+# There are 2 additional ports, both UDP, using low to moderate bandwidth:
+# -- Receive graph/waterfall data from the remote_radio
+# -- Receive radio sound from the remote_radio and send mic samples
 # These use sequential port numbers based on the TCP port number self.remote_ctl_base_port.
 # If you need to change the default base port number, you can edit the line in this file
 # that looks like (without the #):
 #
-#   self.remote_ctl_base_port = 4585		# Remote Control base port
+#   self.remote_ctl_base_port = 4585		# Remote Control base TCP port
+#   self.graph_data_port = self.remote_ctl_base_port + 1		# UDP port for graph data
+#   self.remote_radio_sound_port = self.remote_ctl_base_port + 2	# UDP port for radio sound and mic
 #
 # Make sure to edit the corresponding line in remote_common.py to match ports!!
 #
@@ -73,8 +74,8 @@ class ControlCommon(BaseHardware):	# This is the Hardware class for the control
     self.remote_ctl_timestamp = None
     self.graph_data_port = self.remote_ctl_base_port + 1
     self.remote_radio_sound_port = self.remote_ctl_base_port + 2
-    self.remote_mic_sound_port = self.remote_ctl_base_port + 3
     self.thread_lock = threading.Lock()
+    self.remote_radio_ip = socket.gethostbyname(self.conf.remote_radio_ip)	# Allow either host name or IP address
 
     self.cw_keydown = 0
     self.cw_phrase_begin_ts = None	# timestamp of beginning of cw phrase
@@ -137,7 +138,7 @@ class ControlCommon(BaseHardware):	# This is the Hardware class for the control
       self.remote_ctl_socket.setsockopt(socket.IPPROTO_IP, socket.IP_TOS, 184)	# DSCP "Expedite" (46)
       self.remote_ctl_socket.settimeout(1.0)	# Allow some time for connection response
     try:
-      self.remote_ctl_socket.connect((self.conf.remote_radio_ip, self.remote_ctl_base_port))
+      self.remote_ctl_socket.connect((self.remote_radio_ip, self.remote_ctl_base_port))
     except OSError as err:
       if DEBUG: print("Remote Control socket.connect() error: {0}".format(err))
       return False      # Failure to connect
@@ -297,8 +298,7 @@ class ControlCommon(BaseHardware):	# This is the Hardware class for the control
           print ("Error: Missing password on control head")
       elif reply[0:8] == "TOKEN_OK":
         self.app.main_frame.SetConfigText("Connected to remote radio " + self.conf.remote_radio_ip)
-        QS.start_control_head_remote_sound(self.conf.remote_radio_ip, self.remote_radio_sound_port,
-                 self.remote_mic_sound_port, self.graph_data_port)
+        QS.start_control_head_remote_sound(self.remote_radio_ip, self.remote_radio_sound_port, self.graph_data_port)
         self.CommonInit()	# Send initial parameters common to all radios
         self.RadioInit()	# Send initial parameters peculiar to a given radio
       elif reply[0:9] == "TOKEN_BAD":
@@ -326,7 +326,8 @@ class ControlCommon(BaseHardware):	# This is the Hardware class for the control
     value = app.midiControls[name][0].button.slider_value
     self.RemoteCtlSend("%s;%d\n" % (name, value))
     btn = app.filterButns.GetSelectedButton()
-    self.RemoteCtlSend("%s;%d\n" % (btn.idName, btn.GetIndex()))
+    if btn:
+      self.RemoteCtlSend("%s;%d\n" % (btn.idName, btn.GetIndex()))
     # AGC and Squelch levels, split offset
     self.RemoteCtlSend("Split;0\n")
     btn = app.BtnAGC
