@@ -24,15 +24,17 @@
 # The main control interface between control_head and remote_radio is via a TCP port;
 # this uses very low bandwidth.  All functional control, including CW keying, is done via this port.
 #
-# There are 3 additional ports, all UDP, using low to moderate bandwidth:
-# -- Send graph/waterfall data to the control_head Quisk
-# -- Send radio sound to the control_head Quisk
-# -- Receive mic sound from the control_head Quisk
+# There are 2 additional ports, both UDP, using low to moderate bandwidth:
+# -- Send graph/waterfall data to the control_head
+# -- Send radio sound to the control_head, and receive mic sound
 # These use sequential port numbers based on the TCP port number self.remote_ctl_base_port.
 # If you need to change the default base port number, you can edit the line in this file
 # that looks like (without the #):
 #
-#   self.remote_ctl_base_port = 4585		# Remote Control base port
+#   self.remote_ctl_base_port = 4585		# Remote Control base TCP port
+#   self.graph_data_port = self.remote_ctl_base_port + 1		# UDP port for graph data from the remote
+#   self.remote_radio_sound_port = self.remote_ctl_base_port + 2	# UDP port for radio sound and mic samples
+#
 #
 # Make sure to edit the corresponding line in control_common.py to match ports!!
 #
@@ -51,14 +53,13 @@ DEBUG_CW_JITTER = 0
 DEBUG = 0
 
 from collections import deque	# for CW event queue
-import socket, time, traceback, string, hmac, secrets
+import socket, time, traceback, string, hmac, secrets, json
 import _quisk as QS
 from quisk_widgets import *
 
 class Remot:	# Remote comtrol base class
   def __init__(self, app, conf):
     self.app = app			# Access Quisk class App (Python) functions
-    app.remote_control_slave = True
     self.conf = conf
     self.token = "abc"
     self.token_time = 0
@@ -71,7 +72,6 @@ class Remot:	# Remote comtrol base class
     self.remote_ctl_heartbeat_timeout = 10.0	# Close our connection if we don't hear heartbeat from Control Head
     self.graph_data_port = self.remote_ctl_base_port + 1
     self.remote_radio_sound_port = self.remote_ctl_base_port + 2
-    self.remote_mic_sound_port = self.remote_ctl_base_port + 3
 
     self.cw_delay = 0.020	# time delay to absorb WiFi jitter, in secs
     self.cw_phrase_begin_ts = None	# timestamp of beginning of cw phrase
@@ -87,7 +87,6 @@ class Remot:	# Remote comtrol base class
     self.params = None		# params = the string following the command
     self.extended = None
     self.split_mode = 0
-    QS.set_sparams(remote_control_head=0, remote_control_slave=1)
 
     print('Remote Overlay Initialized!')
 
@@ -121,6 +120,8 @@ class Remot:	# Remote comtrol base class
     except:
       return
     else:
+      self.app.remote_control_slave = True
+      QS.set_sparams(remote_control_slave=1)
       self.token = secrets.token_hex(32)
       self.remote_ctl_connection.settimeout(0.0)
       self.remote_ctl_heartbeat_ts = time.time()
@@ -139,6 +140,8 @@ class Remot:	# Remote comtrol base class
       self.remote_ctl_connection.close()
     self.remote_ctl_connection = None
     QS.stop_remote_radio_remote_sound()
+    self.app.remote_control_slave = False
+    QS.set_sparams(remote_control_slave=0)
 
   def RemoteCtlSend(self, text):
     # Send text back to the client
@@ -223,12 +226,12 @@ class Remot:	# Remote comtrol base class
             self.RemoteCtlSend("TOKEN_OK\n")
             self.remote_ctl_heartbeat_ts = time.time()
             QS.start_remote_radio_remote_sound(self.control_head_ip, self.remote_radio_sound_port,
-                       self.remote_mic_sound_port, self.graph_data_port, self.control_head_data_width)
+                       self.graph_data_port, self.control_head_data_width)
           else:
             time.sleep(1)
         elif time.time() - self.token_time > 5:
           self.RemoteCtlSend("TOKEN_BAD\n")
-          self.RemoteCtlClose(TRUE)
+          self.RemoteCtlClose(True)
           print ("Security failed")
         continue
       # Check for Quit and Heartbeat before any other commands
@@ -274,6 +277,16 @@ class Remot:	# Remote comtrol base class
           sample_rate = self.VarDecimSet(var_decim_index)
           print ("sample_rate", sample_rate)
           self.app.OnBtnDecimation(rate=sample_rate)
+      # Json function call
+      elif command == 'JsonAppFunc':
+        # Call the function self.app. + func with the specified arguments
+        # func = "%s.SetLabel" % self.idName
+        # application.Hardware.RemoteCtlSend(f'JsonAppFunc;{json.dumps((func, label, do_cmd, direction))}\n')
+        jargs = json.loads(params[0])
+        pyobj = self.app
+        for nam in jargs[0].split('.'):
+          pyobj = getattr(pyobj, nam)
+        pyobj(*jargs[1:])
       # AGC and Squelch levels
       elif command == 'AGCSQLCH':
         ctrl = self.app.midiControls["AGCSlider"][0]
