@@ -4,7 +4,7 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-import sys, re
+import sys, re, json
 import wx, wx.lib.buttons, wx.lib.stattext
 # The main script will alter quisk_conf_defaults to include the user's config file.
 import quisk_conf_defaults as conf
@@ -286,6 +286,8 @@ class SliderBoxH:
     value = int(value + 0.5)
     self.SetValue(value)
     if do_cmd:
+      if application.remote_control_head:
+        application.Hardware.RemoteCtlSend(f'{self.idName};{self.GetValue()}\n')
       self.handler(None)
 
 class SliderBoxHH(SliderBoxH, wx.BoxSizer):
@@ -594,6 +596,8 @@ class QuiskPushbutton(QuiskButtons, wx.lib.buttons.GenButton):
     self.direction = 1
   def SetIndex(self, index):
     if self.command and index:
+      if application.remote_control_head:
+        application.Hardware.RemoteCtlSend(self.idName + ';1\n')
       event = wx.PyEvent()
       event.SetEventObject(self)
       self.command(event)
@@ -688,6 +692,8 @@ class QuiskCheckbutton(QuiskButtons, wx.lib.buttons.GenToggleButton):
     wx.lib.buttons.GenToggleButton.SetValue(self, value)
     self.button_down = value
     if do_cmd and self.command:
+      if application.remote_control_head:
+        application.Hardware.RemoteCtlSend(f'{self.idName};{self.GetIndex()}\n')
       event = wx.PyEvent()
       event.SetEventObject(self)
       self.command(event)
@@ -1106,6 +1112,8 @@ class QuiskCycleCheckbutton(QuiskCheckbutton):
     QuiskCheckbutton.SetLabel(self, label)
     QuiskCheckbutton.SetValue(self, self.index)
     if do_cmd and self.command:
+      if application.remote_control_head:
+        application.Hardware.RemoteCtlSend(f'{self.idName};{self.GetIndex()}\n')
       event = wx.PyEvent()
       event.SetEventObject(self)
       self.command(event)
@@ -1114,6 +1122,8 @@ class QuiskCycleCheckbutton(QuiskCheckbutton):
     QuiskCheckbutton.SetLabel(self, self.labels[index])
     QuiskCheckbutton.SetValue(self, index)
     if do_cmd and self.command:
+      if application.remote_control_head:
+        application.Hardware.RemoteCtlSend(f'{self.idName};{self.GetIndex()}\n')
       event = wx.PyEvent()
       event.SetEventObject(self)
       self.command(event)
@@ -1209,6 +1219,9 @@ class RadioButtonGroup:
     else:
       button.command = self.OnButton
   def SetLabel(self, label, do_cmd=False, direction=None):
+    if application.remote_control_head:
+      func = "%s.SetLabel" % self.idName
+      application.Hardware.RemoteCtlSend(f'JsonAppFunc;{json.dumps((func, label, do_cmd, direction))}\n')
     self.button = None
     for b in self.buttons:
       if self.button is not None:
